==> tiltfive_sdk_1.3.3.tar.xz: tiltfive_sdk_1.3.3/Native/docs/html/a00026.js <==
var a00026 =
[
    [ "T5_MAX_STRING_PARAM_LEN", "a00042.html#ga1b3b29732a2474ff4402ff61d29a3f21", null ],
    [ "T5_MIN_CAM_IMAGE_BUFFER_HEIGHT", "a00042.html#ga99712d1b964abea122be49d59842e41d", null ],
    [ "T5_MIN_CAM_IMAGE_BUFFER_WIDTH", "a00042.html#ga14cf6474c4983550efa3be86b46e3798", null ],
    [ "T5_Context", "a00042.html#ga65a594a65a15851444a8c4d5ee389818", null ],
    [ "T5_Glasses", "a00042.html#gac4f432bf3aa06969958dc302864f5215", null ],
    [ "T5_WandHandle", "a00042.html#ga6311f747ef0d46f84925ff937e5f8ea7", null ],
    [ "T5_ConnectionState", "a00042.html#ga2b3c0226f304c432d3a22bdc63a1e809", [
      [ "kT5_ConnectionState_ExclusiveConnection", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809a209ce6ca5ecaa99d2697b0a5b312fae8", null ],
      [ "kT5_ConnectionState_ExclusiveReservation", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809add52e041c8ad2ba2fb18514d53f78f10", null ],
      [ "kT5_ConnectionState_NotExclusivelyConnected", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809ad9874a0d133c9c7f51f9c0be38bce4f9", null ],
      [ "kT5_ConnectionState_Disconnected", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809a1864051ad4bcf48d74423ffc29343e87", null ]
    ] ],
    [ "T5_GameboardType", "a00042.html#ga8eb53e95249a4e9c9198ea0b61c0f0f0", [
      [ "kT5_GameboardType_None", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a741717ee2d873513bfc1983d42e3954b", null ],
      [ "kT5_GameboardType_LE", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a2ff343485cedf2de95a5d6868f9b42d3", null ],
      [ "kT5_GameboardType_XE", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a44dca63b7f2fed0f04eafafc432304ea", null ],
      [ "kT5_GameboardType_XE_Raised", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a9655c14bcbe9853954252b65b6ffc952", null ]
    ] ],
    [ "T5_GlassesPoseUsage", "a00042.html#gadec14b70792f6440b43512cbc9b0c42a", [
      [ "kT5_GlassesPoseUsage_GlassesPresentation", "a00042.html#ggadec14b70792f6440b43512cbc9b0c42aa82298e2e92a43ec9a14271d65bd223f4", null ],
      [ "kT5_GlassesPoseUsage_SpectatorPresentation", "a00042.html#ggadec14b70792f6440b43512cbc9b0c42aaf15ed38c3ec3110b87e4627c5e84ed1a", null ]
    ] ],
    [ "T5_GraphicsApi", "a00042.html#ga678f083cec65b241415377200c0ebe98", [
      [ "kT5_GraphicsApi_None", "a00042.html#gga678f083cec65b241415377200c0ebe98a45ff8b084a51568b3d4e1e01a374199d", null ],
      [ "kT5_GraphicsApi_GL", "a00042.html#gga678f083cec65b241415377200c0ebe98ad56e5aa72bd7ebc17e4dad45e63d321c", null ],
      [ "kT5_GraphicsApi_D3D11", "a00042.html#gga678f083cec65b241415377200c0ebe98a89c173a38fa54af54530472ec143f35a", null ]
    ] ],
    [ "T5_Hand", "a00042.html#ga6b9a746c9e53f032b5401a88fc06da17", [
      [ "kT5_Hand_Unknown", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17aa6ab7cfe069e20703150094877525136", null ],
      [ "kT5_Hand_Left", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17aefc52aefa94b5f145b55cbc94d9492a9", null ],
      [ "kT5_Hand_Right", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17a7c338a2dcb57320b18075fdd2685af28", null ]
    ] ],
    [ "T5_ParamGlasses", "a00042.html#ga5febd253ae9871a4b46ec353e68a72b1", [
      [ "kT5_ParamGlasses_Float_IPD", "a00042.html#gga5febd253ae9871a4b46ec353e68a72b1a220326561276f9f3c90c9a1035abc7b4", null ],
      [ "kT5_ParamGlasses_UTF8_FriendlyName", "a00042.html#gga5febd253ae9871a4b46ec353e68a72b1a407885fd7cd9d56a5c3b931c9ab8b9ed", null ]
    ] ],
    [ "T5_ParamSys", "a00042.html#ga8461e4e8585f0bedb85c4a555ee1c7d1", [
      [ "kT5_ParamSys_UTF8_Service_Version", "a00042.html#gga8461e4e8585f0bedb85c4a555ee1c7d1a5ef3b1249be4b2b5f57ebfd28090b002", null ],
      [ "kT5_ParamSys_Integer_CPL_AttRequired", "a00042.html#gga8461e4e8585f0bedb85c4a555ee1c7d1a510e779bbd5c259c72f9909f63507d7c", null ]
    ] ],
    [ "T5_WandStreamEventType", "a00042.html#gab24ef720ba130bc53642b696ee375919", [
      [ "kT5_WandStreamEventType_Connect", "a00042.html#ggab24ef720ba130bc53642b696ee375919a167d45ce1b088d96144f1e6c1874a385", null ],
      [ "kT5_WandStreamEventType_Disconnect", "a00042.html#ggab24ef720ba130bc53642b696ee375919a601cf31d6b7c28cb9f7956d46add3282", null ],
      [ "kT5_WandStreamEventType_Desync", "a00042.html#ggab24ef720ba130bc53642b696ee375919abff736b608e692d9ebdd2639fd4c27b3", null ],
      [ "kT5_WandStreamEventType_Report", "a00042.html#ggab24ef720ba130bc53642b696ee375919a722acef440298a67d4f3402099bfbaa6", null ]
    ] ]
];

==> tiltfive_sdk_1.4.0.tar.xz: tiltfive_sdk_1.4.0/Native/docs/html/a00026.js <==
var a00026 =
[
    [ "T5_MAX_STRING_PARAM_LEN", "a00042.html#ga1b3b29732a2474ff4402ff61d29a3f21", null ],
    [ "T5_MIN_CAM_IMAGE_BUFFER_HEIGHT", "a00042.html#ga99712d1b964abea122be49d59842e41d", null ],
    [ "T5_MIN_CAM_IMAGE_BUFFER_WIDTH", "a00042.html#ga14cf6474c4983550efa3be86b46e3798", null ],
    [ "T5_Context", "a00042.html#ga65a594a65a15851444a8c4d5ee389818", null ],
    [ "T5_Glasses", "a00042.html#gac4f432bf3aa06969958dc302864f5215", null ],
    [ "T5_WandHandle", "a00042.html#ga6311f747ef0d46f84925ff937e5f8ea7", null ],
    [ "T5_CartesianCoordinateHandedness", "a00042.html#gae39946a8688f627cb4bfa7af5b6a4f4d", [
      [ "kT5_CartesianCoordinateHandedness_Left", "a00042.html#ggae39946a8688f627cb4bfa7af5b6a4f4da0d114b3f915b788a96aad09ed3b40714", null ],
      [ "kT5_CartesianCoordinateHandedness_Right", "a00042.html#ggae39946a8688f627cb4bfa7af5b6a4f4da283cf76a80d045f7fb17790e4358b442", null ]
    ] ],
    [ "T5_ConnectionState", "a00042.html#ga2b3c0226f304c432d3a22bdc63a1e809", [
      [ "kT5_ConnectionState_ExclusiveConnection", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809a209ce6ca5ecaa99d2697b0a5b312fae8", null ],
      [ "kT5_ConnectionState_ExclusiveReservation", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809add52e041c8ad2ba2fb18514d53f78f10", null ],
      [ "kT5_ConnectionState_NotExclusivelyConnected", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809ad9874a0d133c9c7f51f9c0be38bce4f9", null ],
      [ "kT5_ConnectionState_Disconnected", "a00042.html#gga2b3c0226f304c432d3a22bdc63a1e809a1864051ad4bcf48d74423ffc29343e87", null ]
    ] ],
    [ "T5_DepthRange", "a00042.html#ga63b985ebdd413b6ae951689a84d33122", [
      [ "kT5_DepthRange_MinusOneToOne", "a00042.html#gga63b985ebdd413b6ae951689a84d33122a68ab65cc93016c0a91a17bbb888bb3c9", null ],
      [ "kT5_DepthRange_ZeroToOne", "a00042.html#gga63b985ebdd413b6ae951689a84d33122a1d2f3afeb7a2cf00c4215aa90bbd0fea", null ]
    ] ],
    [ "T5_GameboardType", "a00042.html#ga8eb53e95249a4e9c9198ea0b61c0f0f0", [
      [ "kT5_GameboardType_None", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a741717ee2d873513bfc1983d42e3954b", null ],
      [ "kT5_GameboardType_LE", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a2ff343485cedf2de95a5d6868f9b42d3", null ],
      [ "kT5_GameboardType_XE", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a44dca63b7f2fed0f04eafafc432304ea", null ],
      [ "kT5_GameboardType_XE_Raised", "a00042.html#gga8eb53e95249a4e9c9198ea0b61c0f0f0a9655c14bcbe9853954252b65b6ffc952", null ]
    ] ],
    [ "T5_GlassesPoseUsage", "a00042.html#gadec14b70792f6440b43512cbc9b0c42a", [
      [ "kT5_GlassesPoseUsage_GlassesPresentation", "a00042.html#ggadec14b70792f6440b43512cbc9b0c42aa82298e2e92a43ec9a14271d65bd223f4", null ],
      [ "kT5_GlassesPoseUsage_SpectatorPresentation", "a00042.html#ggadec14b70792f6440b43512cbc9b0c42aaf15ed38c3ec3110b87e4627c5e84ed1a", null ]
    ] ],
    [ "T5_GraphicsApi", "a00042.html#ga678f083cec65b241415377200c0ebe98", [
      [ "kT5_GraphicsApi_None", "a00042.html#gga678f083cec65b241415377200c0ebe98a45ff8b084a51568b3d4e1e01a374199d", null ],
      [ "kT5_GraphicsApi_GL", "a00042.html#gga678f083cec65b241415377200c0ebe98ad56e5aa72bd7ebc17e4dad45e63d321c", null ],
      [ "kT5_GraphicsApi_D3D11", "a00042.html#gga678f083cec65b241415377200c0ebe98a89c173a38fa54af54530472ec143f35a", null ],
      [ "kT5_GraphicsApi_Vulkan", "a00042.html#gga678f083cec65b241415377200c0ebe98a22cbb8c6df67e84919ef5325dd9334d3", null ]
    ] ],
    [ "T5_GraphicsApi_GL_TextureMode", "a00042.html#ga0afe662a45969196b8178536343e77b6", [
      [ "kT5_GraphicsApi_GL_TextureMode_Pair", "a00042.html#gga0afe662a45969196b8178536343e77b6a2b8a55dd2e985e2135b614b50e58c687", null ],
      [ "kT5_GraphicsApi_GL_TextureMode_Array", "a00042.html#gga0afe662a45969196b8178536343e77b6a530e10a2664ff007ecd0c181b1c45f26", null ]
    ] ],
    [ "T5_GraphicsApi_Vulkan_TextureMode", "a00042.html#ga75586c7593e3e18980b6852ab021e3ba", [
      [ "kT5_GraphicsApi_Vulkan_TextureMode_Image", "a00042.html#gga75586c7593e3e18980b6852ab021e3baa15d72d0eb5f88a84a6683508b3928e8b", null ],
      [ "kT5_GraphicsApi_Vulkan_TextureMode_ImageView", "a00042.html#gga75586c7593e3e18980b6852ab021e3baa97b95a56c9b2264de2f27f0b2593f8b8", null ]
    ] ],
    [ "T5_Hand", "a00042.html#ga6b9a746c9e53f032b5401a88fc06da17", [
      [ "kT5_Hand_Unknown", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17aa6ab7cfe069e20703150094877525136", null ],
      [ "kT5_Hand_Left", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17aefc52aefa94b5f145b55cbc94d9492a9", null ],
      [ "kT5_Hand_Right", "a00042.html#gga6b9a746c9e53f032b5401a88fc06da17a7c338a2dcb57320b18075fdd2685af28", null ]
    ] ],
    [ "T5_MatrixOrder", "a00042.html#ga42282e79797114b5fbf86fde71ae0397", [
      [ "kT5_MatrixOrder_RowMajor", "a00042.html#gga42282e79797114b5fbf86fde71ae0397afa1f3df3b96340be6bb75a44d31232a0", null ],
      [ "kT5_MatrixOrder_ColumnMajor", "a00042.html#gga42282e79797114b5fbf86fde71ae0397ac4ac79d67b0f3e78b7587d6253143157", null ]
    ] ],
    [ "T5_ParamGlasses", "a00042.html#ga5febd253ae9871a4b46ec353e68a72b1", [
      [ "kT5_ParamGlasses_Float_IPD", "a00042.html#gga5febd253ae9871a4b46ec353e68a72b1a220326561276f9f3c90c9a1035abc7b4", null ],
      [ "kT5_ParamGlasses_UTF8_FriendlyName", "a00042.html#gga5febd253ae9871a4b46ec353e68a72b1a407885fd7cd9d56a5c3b931c9ab8b9ed", null ]
    ] ],
    [ "T5_ParamSys", "a00042.html#ga8461e4e8585f0bedb85c4a555ee1c7d1", [
      [ "kT5_ParamSys_UTF8_Service_Version", "a00042.html#gga8461e4e8585f0bedb85c4a555ee1c7d1a5ef3b1249be4b2b5f57ebfd28090b002", null ],
      [ "kT5_ParamSys_Integer_CPL_AttRequired", "a00042.html#gga8461e4e8585f0bedb85c4a555ee1c7d1a510e779bbd5c259c72f9909f63507d7c", null ]
    ] ],
    [ "T5_WandStreamEventType", "a00042.html#gab24ef720ba130bc53642b696ee375919", [
      [ "kT5_WandStreamEventType_Connect", "a00042.html#ggab24ef720ba130bc53642b696ee375919a167d45ce1b088d96144f1e6c1874a385", null ],
      [ "kT5_WandStreamEventType_Disconnect", "a00042.html#ggab24ef720ba130bc53642b696ee375919a601cf31d6b7c28cb9f7956d46add3282", null ],
      [ "kT5_WandStreamEventType_Desync", "a00042.html#ggab24ef720ba130bc53642b696ee375919abff736b608e692d9ebdd2639fd4c27b3", null ],
      [ "kT5_WandStreamEventType_Report", "a00042.html#ggab24ef720ba130bc53642b696ee375919a722acef440298a67d4f3402099bfbaa6", null ]
    ] ]
];
